macro_rules! impl_registry_entry {
($Entry:ty, $global_field:ident) => { ... };
}Expand description
Implements RegistryEntry for an entry type via hash map lookup.
macro_rules! impl_registry_entry {
($Entry:ty, $global_field:ident) => { ... };
}Implements RegistryEntry for an entry type via hash map lookup.