macro_rules! impl_standard_methods {
($Registry:ty, $Entry:ty, $id_field:ident, $key_field:ident, $allow_registering:ident) => { ... };
}Expand description
Implements the default register, replace, and iter methods in the registries
macro_rules! impl_standard_methods {
($Registry:ty, $Entry:ty, $id_field:ident, $key_field:ident, $allow_registering:ident) => { ... };
}Implements the default register, replace, and iter methods in the registries